/* Generated by wayland-scanner 1.26.0 */

/*
 * Copyright © 2021-2023 Andri Yngvason
 * Copyright © 2024 Simon Ser
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"

extern const struct wl_interface ext_image_capture_source_v1_interface;
extern const struct wl_interface ext_image_copy_capture_cursor_session_v1_interface;
extern const struct wl_interface ext_image_copy_capture_frame_v1_interface;
extern const struct wl_interface ext_image_copy_capture_session_v1_interface;
extern const struct wl_interface wl_buffer_interface;
extern const struct wl_interface wl_pointer_interface;

static const struct wl_interface *ext_image_copy_capture_v1_types[] = {
	NULL,
	NULL,
	NULL,
	NULL,
	&ext_image_copy_capture_session_v1_interface,
	&ext_image_capture_source_v1_interface,
	NULL,
	&ext_image_copy_capture_cursor_session_v1_interface,
	&ext_image_capture_source_v1_interface,
	&wl_pointer_interface,
	&ext_image_copy_capture_frame_v1_interface,
	&wl_buffer_interface,
	&ext_image_copy_capture_session_v1_interface,
};

static const struct wl_message ext_image_copy_capture_manager_v1_requests[] = {
	{ "create_session", "nou", ext_image_copy_capture_v1_types + 4 },
	{ "create_pointer_cursor_session", "noo", ext_image_copy_capture_v1_types + 7 },
	{ "destroy", "", ext_image_copy_capture_v1_types + 0 },
};

WL_EXPORT const struct wl_interface ext_image_copy_capture_manager_v1_interface = {
	"ext_image_copy_capture_manager_v1", 1,
	3, ext_image_copy_capture_manager_v1_requests,
	0, NULL,
};

static const struct wl_message ext_image_copy_capture_session_v1_requests[] = {
	{ "create_frame", "n", ext_image_copy_capture_v1_types + 10 },
	{ "destroy", "", ext_image_copy_capture_v1_types + 0 },
};

static const struct wl_message ext_image_copy_capture_session_v1_events[] = {
	{ "buffer_size", "uu", ext_image_copy_capture_v1_types + 0 },
	{ "shm_format", "u", ext_image_copy_capture_v1_types + 0 },
	{ "dmabuf_device", "a", ext_image_copy_capture_v1_types + 0 },
	{ "dmabuf_format", "ua", ext_image_copy_capture_v1_types + 0 },
	{ "done", "", ext_image_copy_capture_v1_types + 0 },
	{ "stopped", "", ext_image_copy_capture_v1_types + 0 },
};

WL_EXPORT const struct wl_interface ext_image_copy_capture_session_v1_interface = {
	"ext_image_copy_capture_session_v1", 1,
	2, ext_image_copy_capture_session_v1_requests,
	6, ext_image_copy_capture_session_v1_events,
};

static const struct wl_message ext_image_copy_capture_frame_v1_requests[] = {
	{ "destroy", "", ext_image_copy_capture_v1_types + 0 },
	{ "attach_buffer", "o", ext_image_copy_capture_v1_types + 11 },
	{ "damage_buffer", "iiii", ext_image_copy_capture_v1_types + 0 },
	{ "capture", "", ext_image_copy_capture_v1_types + 0 },
};

static const struct wl_message ext_image_copy_capture_frame_v1_events[] = {
	{ "transform", "u", ext_image_copy_capture_v1_types + 0 },
	{ "damage", "iiii", ext_image_copy_capture_v1_types + 0 },
	{ "presentation_time", "uuu", ext_image_copy_capture_v1_types + 0 },
	{ "ready", "", ext_image_copy_capture_v1_types + 0 },
	{ "failed", "u", ext_image_copy_capture_v1_types + 0 },
};

WL_EXPORT const struct wl_interface ext_image_copy_capture_frame_v1_interface = {
	"ext_image_copy_capture_frame_v1", 1,
	4, ext_image_copy_capture_frame_v1_requests,
	5, ext_image_copy_capture_frame_v1_events,
};

static const struct wl_message ext_image_copy_capture_cursor_session_v1_requests[] = {
	{ "destroy", "", ext_image_copy_capture_v1_types + 0 },
	{ "get_capture_session", "n", ext_image_copy_capture_v1_types + 12 },
};

static const struct wl_message ext_image_copy_capture_cursor_session_v1_events[] = {
	{ "enter", "", ext_image_copy_capture_v1_types + 0 },
	{ "leave", "", ext_image_copy_capture_v1_types + 0 },
	{ "position", "ii", ext_image_copy_capture_v1_types + 0 },
	{ "hotspot", "ii", ext_image_copy_capture_v1_types + 0 },
};

WL_EXPORT const struct wl_interface ext_image_copy_capture_cursor_session_v1_interface = {
	"ext_image_copy_capture_cursor_session_v1", 1,
	2, ext_image_copy_capture_cursor_session_v1_requests,
	4, ext_image_copy_capture_cursor_session_v1_events,
};

